==> sigutils-2.4.2.tar.gz: sigutils-2.4.2/SigUtils/cpf.py <==
__Autor__ = "Luiz Fernando"
__Empresa__ = "Sig Informatica Ltda"
__Site__ = "http://www.siginformatica.com.br"
__Versao__ = "1.04"
__DataAlteracao__ = "23/01/2009"
import sys
if __name__ == '__main__':
    try:
        if sys.argv[1] == '-9':
            print('cpf.py\t\t\tVersao:' + __Versao__ + '\tData:'+ __DataAlteracao__) + '\tValidador/Formator de CPFs '
        else:
           print('\n\ncpf.py - Validador/Formator de CPFs \n'
                   +'Versao: '+ __Versao__ + '\n'
                   +'Data: '+ __DataAlteracao__ + '\n')
    except:
       print('\n\ncpf.py - Validador/Formator de CPFs \n'
               +'Versao: '+ __Versao__ + '\n'
               +'Data: '+ __DataAlteracao__ + '\n')

class Cpf:
    def __init__( self ):
        """
        Classe para testar numeros de CPF
        """
        pass

    def format( self, cpf ):
        """
        Metodo para formatar CPF

        Tests:
        >>> print Cpf().format('91289037736')
        912.890.377-36
        """
        return "%s.%s.%s-%s" % ( cpf[0:3], cpf[3:6], cpf[6:9], cpf[9:11] )

    def validar( self, cpf, force=False ):
        """
        Metodo para validar cpf
        Force = True, retorna o cpf com o digito correto.

        Testes:
        >>> print Cpf().validar('91289037736')
        True
        >>> print Cpf().validar('91289037731')
        False
        """

        if not cpf.isdigit():
            """ Verifica se o CPF contem pontos e hifens """
            cpf = cpf.replace(".", "")
            cpf = cpf.replace("-", "")

        if len(cpf) < 11:
            """ Verifica se o CPF tem 11 digitos """
            return False

        if len(cpf) > 11:
            """ CPF tem que ter 11 digitos """
            return False

        selfcpf = [int(x) for x in cpf]
        cpf = selfcpf[:9]
        while len(cpf) < 11:
            r =  sum([(len(cpf)+1-i)*v for i,v in [(x,cpf[x]) for x in range(len(cpf))]]) % 11
            if r > 1:
                f = 11 - r
            else:
                f = 0
            cpf.append(f)
        res = bool(cpf == selfcpf)
        if force:
            res = ''
            for x in cpf:
                res += str(x)
            return res
        return res

# test
import doctest ; doctest.testmod()

==> sigutils-3.1.11.tar.gz: sigutils-3.1.11/SigUtils/cpf.py <==
__Autor__ = "Luiz Fernando"
__Empresa__ = "Sig Informatica Ltda"
__Site__ = "http://www.siginformatica.com.br"
__Versao__ = "1.04"
__DataAlteracao__ = "23/01/2009"
import sys
if __name__ == '__main__':
    try:
        if sys.argv[1] == '-9':
            print(('cpf.py\t\t\tVersao:' + __Versao__ + '\tData:'+ __DataAlteracao__) +
                  '\tValidador/Formator de CPFs ')
        else:
            print(('\n\ncpf.py - Validador/Formator de CPFs \n' + 'Versao: '+ __Versao__ + '\n' +
                  'Data: '+ __DataAlteracao__ + '\n'))
    except:
        print(('\n\ncpf.py - Validador/Formator de CPFs \n' + 'Versao: '+ __Versao__ + '\n' +
              'Data: '+ __DataAlteracao__ + '\n'))


class Cpf:
    def __init__( self ):
        """
        Classe para testar numeros de CPF
        """
        pass

    def format( self, cpf ):
        """
        Metodo para formatar CPF

        Tests:
        # >>> print Cpf().format('91289037736')
        912.890.377-36
        """
        return "%s.%s.%s-%s" % ( cpf[0:3], cpf[3:6], cpf[6:9], cpf[9:11] )

    def validar( self, cpf, force=False ):
        """
        Metodo para validar cpf
        Force = True, retorna o cpf com o digito correto.

        Testes:
        # >>> print Cpf().validar('91289037736')
        True
        # >>> print Cpf().validar('91289037731')
        False
        """

        if not cpf.isdigit():
            """ Verifica se o CPF contem pontos e hifens """
            cpf = cpf.replace(".", "")
            cpf = cpf.replace("-", "")

        if len(cpf) < 11:
            """ Verifica se o CPF tem 11 digitos """
            return False

        if len(cpf) > 11:
            """ CPF tem que ter 11 digitos """
            return False

        selfcpf = [int(x) for x in cpf]
        cpf = selfcpf[:9]
        while len(cpf) < 11:
            r =  sum([(len(cpf)+1-i)*v for i,v in [(x,cpf[x]) for x in range(len(cpf))]]) % 11
            if r > 1:
                f = 11 - r
            else:
                f = 0
            cpf.append(f)
        res = bool(cpf == selfcpf)
        if force:
            res = ''
            for x in cpf:
                res += str(x)
            return res
        return res

# test
import doctest ; doctest.testmod()
